@@ -12,8 +12,10 @@ from src.entities.log import Log
 from src.entities.order import Queue, Order
 from src.entities.orderb2b import OrderB2B
 from src.entities.price import Price
-from src.entities.response import CatalogoResponse, PriceResponse, InvoiceResponse, TrackingResponse, StockResponse, ClientResponse
+from src.entities.response import CatalogoResponse, PriceResponse, InvoiceResponse, TrackingResponse, StockResponse, \
+    ClientResponse
 from src.entities.tracking import Tracking
+from src.entities.photos_sku import PhotosSku
 
 logger = logging.getLogger()
 
@@ -119,7 +121,8 @@ def post_prices(url, price: Price, token) -> PriceResponse:
 def get_order_queue(url: str, token: str, status: str, limit: int) -> List[Queue]:
     queue = []
     try:
-        response = requests.get(url.format(status), headers={'Accept': 'application/json', 'access-token': token}, params={'limit': limit})
+        response = requests.get(url.format(status), headers={'Accept': 'application/json', 'access-token': token},
+                                params={'limit': limit})
         if response.ok:
             obj = jsonpickle.decode(response.content)
             for o in obj['fila']:
@@ -166,7 +169,8 @@ def get_order_b2b(url: str, token: str, order_id: int) -> OrderB2B:
 
 def put_order_erp_code(url: str, token: str, order_id: int, order_erp_id: str) -> bool:
     try:
-        response = requests.put(url, headers={'Accept': 'application/json', 'access-token': token}, params={'id': order_id, 'codigo_erp': order_erp_id})
+        response = requests.put(url, headers={'Accept': 'application/json', 'access-token': token},
+                                params={'id': order_id, 'codigo_erp': order_erp_id})
         if response.ok:
             return True
         else:
@@ -180,7 +184,8 @@ def put_order_erp_code(url: str, token: str, order_id: int, order_erp_id: str) -
 def put_client_erp_code(url: str, token: str, body: dict) -> bool:
     try:
         data = jsonpickle.encode(body, unpicklable=False)
-        response = requests.put(url, data=json.loads(data), headers={'Accept': 'application/json', 'access-token': token})
+        response = requests.put(url, data=json.loads(data),
+                                headers={'Accept': 'application/json', 'access-token': token})
         if response.ok:
             return True
         else:
@@ -195,7 +200,9 @@ def put_protocol_orders(protocolos: List[str]) -> bool:
     url = src.client_data.get('url_api') + f'/pedido/fila'
     try:
         json_protocolos = jsonpickle.encode(protocolos)
-        response = requests.put(url, json=json.loads(json_protocolos), headers={'Accept': 'application/json', 'access-token': src.client_data.get('token_api')})
+        response = requests.put(url, json=json.loads(json_protocolos), headers={'Accept': 'application/json',
+                                                                                'access-token': src.client_data.get(
+                                                                                    'token_api')})
         if response.ok:
             return True
         else:
@@ -310,3 +317,36 @@ def post_clients(clients: List[Cliente]) -> List[ClientResponse]:
     except Exception as e:
         return [ClientResponse([c.cpf or c.cnpj for c in clients], 3, str(e))]
 
+
+def put_photos_sku(body: List[PhotosSku]):
+    """
+        Cadastra Fotos do SKU
+        Podem ser enviadas até 50 fotos por vez.
+        Args:
+            url: Url da api okvendas
+            token: Token de acesso da api okvendas
+            photosProduto: Objeto com os dados das Fotos
+        Returns:
+        True se foi atualizado com Sucesso. False se não foi atualizado
+    """
+    try:
+        url = f'{src.client_data.get("url_api")}/v2/catalogo/fotos/sku'
+
+        headers = {'Content-type': 'application/json',
+                   'Accept': 'application/json',
+                   'access-token': src.client_data.get('token_api')}
+
+        json_photos = jsonpickle.encode(body, unpicklable=False)
+        logger.info(f'{url} - {json_photos}')
+
+        response = requests.put(url,
+                                headers=headers,
+                                json=json.loads(json_photos))
+        if response.ok:
+            return True
+        else:
+            logger.warning(f'Retorno sem sucesso {response.status_code} - {response.url}')
+            return False
+    except Exception as ex:
+        logger.error(f'Erro ao realizar PUT /v2/catalogo/fotos/sku na api okvendas {url}' + str(ex), exc_info=True)
+        return False
