@@ -192,7 +192,7 @@ def get_update_client_sql(connection_type: str):
 							WHERE cliente_erp = ? '''
 
 
-def get_query_order(connection_type: str):
+def get_query_non_integrated_order(connection_type: str):
 	if connection_type.lower() == 'mysql':
 		return 'select id from openk_semaforo.pedido where pedido_id = %s and data_sincronizacao is null'
 	elif connection_type.lower() == 'oracle':
@@ -201,6 +201,15 @@ def get_query_order(connection_type: str):
 		return 'select id from openk_semaforo.pedido where pedido_id = ? and data_sincronizacao is null'
 
 
+def get_query_order(connection_type: str):
+	if connection_type.lower() == 'mysql':
+		return 'select id from openk_semaforo.pedido where pedido_id = %s'
+	elif connection_type.lower() == 'oracle':
+		return 'SELECT ID FROM OPENK_SEMAFORO.PEDIDO WHERE PEDIDO_ID = :order_id'
+	elif connection_type.lower() == 'sql':
+		return 'select id from openk_semaforo.pedido where pedido_id = ?'
+
+
 def get_command_parameter(connection_type: str, parameters: list):
 	if connection_type.lower() == 'mysql':
 		return tuple(parameters)
@@ -232,8 +241,8 @@ def get_client_protocol_command(connection_type: str):
 
 def get_out_client_protocol_command(connection_type: str):
 	if connection_type.lower() == 'mysql':
-		return 'update openk_semaforo.cliente set data_sincronizacao = now() where client_erp = %s'
+		return 'update openk_semaforo.cliente set data_sincronizacao = now() where cliente_erp = %s'
 	elif connection_type.lower() == 'oracle':
 		return 'UPDATE OPENK_SEMAFORO.CLIENTE C SET DATA_SINCRONIZACAO = SYSDATE WHERE CLIENTE_ERP = :1 '
 	elif connection_type.lower() == 'sql':
-		return 'update openk_semaforo.cliente set data_sincronizacao = now() where client_erp = ? '
+		return 'update openk_semaforo.cliente set data_sincronizacao = now() where cliente_erp = ? '
