@@ -11,8 +11,10 @@ import src
 import time
 from src.entities.log import Log
 from typing import List
+from src.jobs.system_jobs import OnlineLogger
 
 logger = logging.getLogger()
+send_log = OnlineLogger.send_log
 
 
 def job_insert_prices_semaphore(job_config_dict: dict):
@@ -23,19 +25,19 @@ def job_insert_prices_semaphore(job_config_dict: dict):
     """
     db_config = utils.get_database_config(job_config_dict)
     if db_config.sql is None:
-        logger.warning(job_config_dict.get('job_name') + ' | Comando sql para inserir precos no semaforo nao encontrado')
+        send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f'Comando sql para inserir precos no semaforo nao encontrado', 'warning', 'PRECO')
     else:
         db = database.Connection(db_config)
         conn = db.get_conect()
         cursor = conn.cursor()
 
         try:
-            logger.info(job_config_dict.get('job_name') + ' | Inserindo precos no banco semaforo')
+            send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f'Inserindo precos no banco semaforo', 'info', 'PRECO')
             logger.info(db_config.sql)
             cursor.execute(db_config.sql)
-            logger.info(job_config_dict.get('job_name') + f' | {cursor.rowcount} precos inseridos no banco semaforo')
+            send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f'{cursor.rowcount} precos inseridos no banco semaforo', 'info', 'PRECO')
         except Exception as ex:
-            logger.error(job_config_dict.get('job_name') + ' | Erro ' + str(ex), exc_info=True)
+            send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f'Erro {str(ex)}', 'error', 'PRECO')
 
         cursor.close()
         conn.commit()
@@ -51,34 +53,39 @@ def job_send_prices(job_config_dict: dict):
     try:
         db_config = utils.get_database_config(job_config_dict)
         if db_config.sql is None:
-            logger.warning(job_config_dict.get('job_name') + ' | Comando sql para inserir precos no semaforo nao encontrado')
+            send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f'Comando sql para inserir precos no semaforo nao encontrado', 'warning', 'PRECO')
         else:
-            prices = query_prices(db_config)
+            prices = query_prices(job_config_dict, db_config)
             if prices is not None and len(prices) > 0:
-                logger.info(job_config_dict.get('job_name') + f' | Produtos para atualizar preco {len(prices)}')
+                send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f'Produtos para atualizar preco {len(prices)}', 'info', 'PRECO')
 
                 for price in prices:
                     try:
                         time.sleep(1)
                         response = api_okvendas.post_prices(src.client_data.get('url_api') + '/catalogo/preco', price, src.client_data.get('token_api'))
                         if response.status == 1 or response.status == "Success":
-                            logger.info(job_config_dict.get('job_name') + f' | Protocolando preço do sku {price.codigo_erp}')
+                            send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f'Protocolando preço do sku {price.codigo_erp}', 'info', 'PRECO')
+                            protocol_price(db_config, price)
+                        elif (response.status == 'Error' or response.status > 1) and response.message == "Erro ao atualizar o preço. Produto não existente":
+                            send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False,
+                                          f'Nao foi possivel atualizar o preco do sku {price.codigo_erp}. Erro recebido da Api: {response.message}', 'warning', 'PRECO')
                             protocol_price(db_config, price)
                         else:
-                            logger.warning(job_config_dict.get('job_name') + f' | Nao foi possivel atualizar o preco do sku {price.codigo_erp}. Erro recebido da Api: {response.message}')
-                            api_okvendas.post_log(Log(job_config_dict.get('job_name') + f' | Erro ao atualizar preço do sku {price.codigo_erp}: {response.message}', datetime.now().isoformat(), price.codigo_erp, 'PRECO'))
+                            send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), True,
+                                          f'Nao foi possivel atualizar o preco do sku {price.codigo_erp}. Erro recebido da Api: {response.message}', 'warning', 'PRECO', price.codigo_erp)
                     except Exception as e:
-                        logger.warning(job_config_dict.get('job_name') + f' | Falha ao atualizar preco do sku {price.codigo_erp}: {str(e)}')
+                        send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), True, f'Falha ao atualizar preco do sku {price.codigo_erp}: {str(e)}', 'warning', 'PRECO', price.codigo_erp)
             else:
-                logger.warning(job_config_dict.get('job_name') + ' | Nao existem precos a serem enviados no momento')
+                send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f'Nao existem precos a serem enviados no momento', 'warning', 'PRECO')
     except Exception as e:
-        logger.error(job_config_dict.get('job_name') + f' | Erro durante execucao do job: {e}')
+        send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f'Erro durante execucao do job: {str(e)}', 'error', 'PRECO')
 
 
-def query_prices(db_config: DatabaseConfig) -> List[Price]:
+def query_prices(job_config_dict: dict, db_config: DatabaseConfig) -> List[Price]:
     """
     Consulta os precos para atualizar no banco de dados
     Args:
+        job_config_dict: Configuração do job
         db_config: Configuracao do banco de dados
 
     Returns:
@@ -99,7 +106,7 @@ def query_prices(db_config: DatabaseConfig) -> List[Price]:
             return prices
 
     except Exception as ex:
-        logger.error(f' Erro ao consultar precos no banco semaforo:  {ex}')
+        send_log(job_config_dict.get('job_name'), job_config_dict.get('enviar_logs'), False, f' Erro ao consultar precos no banco semaforo: {str(ex)}', 'error', 'PRECO')
 
     return []
 
@@ -118,7 +125,6 @@ def protocol_price(db_config: DatabaseConfig, price: Price) -> None:
     try:
         cursor.execute(sql, queries.get_command_parameter(db_config.db_type, [price.codigo_erp, price.preco_atual]))
     except Exception as e:
-        logger.warning(f'Erro ao protocolar preco do sku no banco semaforo {price.codigo_erp}: {e}')
         raise Exception(f'Erro ao protocolar preco do sku no banco semaforo {price.codigo_erp}: {str(e)}')
 
     cursor.close()
